package com.link.core.converter.util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.EnumSet;
import java.util.Iterator;
import java.util.List;

public class StringUtil {
   public static final int RADIX_BIN = 2;
   public static final int RADIX_OCT = 8;
   public static final int RADIX_DEC = 10;
   public static final int RADIX_HEX = 16;
   private static final String COMMA = ",";
   public static final String[] TRUE_STRINGS = new String[]{"true", "t", "1", "on", "yes", "y", "是"};
   public static final String[] FALSE_STRINGS = new String[]{"false", "f", "0", "off", "no", "n", "否", "不", "非"};
   public static final String[] DATE_FORMATS = new String[]{"yyyy-M-d HH:mm:ss.SSS", "yyyy-M-d HH:mm:ss", "yyyy-M-d HH:mm", "yyyy-M-d HH", "yyyy-M-d"};
   public static final String DEFAULT_DATE_FORMAT = "yyyy-M-d HH:mm:ss.SSS";

   public static boolean isNullOrEmpty(String str) {
      return str == null || "".equals(str);
   }

   public static boolean isNullOrBlank(String str) {
      return str == null || "".equals(str.trim());
   }

   public static Boolean toBoolean(String str) {
      if (str == null) {
         return null;
      } else {
         str = str.trim().toLowerCase();
         String[] var1 = TRUE_STRINGS;
         int var2 = var1.length;

         int var3;
         String s;
         for(var3 = 0; var3 < var2; ++var3) {
            s = var1[var3];
            if (s.equals(str)) {
               return Boolean.TRUE;
            }
         }

         var1 = FALSE_STRINGS;
         var2 = var1.length;

         for(var3 = 0; var3 < var2; ++var3) {
            s = var1[var3];
            if (s.equals(str)) {
               return Boolean.FALSE;
            }
         }

         return null;
      }
   }

   public static Boolean toBoolean(String str, boolean defaultValue) {
      if (isNullOrBlank(str)) {
         return defaultValue;
      } else {
         str = str.trim().toLowerCase();
         String[] var2;
         int var3;
         int var4;
         String s;
         if (defaultValue) {
            var2 = FALSE_STRINGS;
            var3 = var2.length;

            for(var4 = 0; var4 < var3; ++var4) {
               s = var2[var4];
               if (s.equals(str)) {
                  return Boolean.FALSE;
               }
            }

            return Boolean.TRUE;
         } else {
            var2 = TRUE_STRINGS;
            var3 = var2.length;

            for(var4 = 0; var4 < var3; ++var4) {
               s = var2[var4];
               if (s.equals(str)) {
                  return Boolean.TRUE;
               }
            }

            return Boolean.FALSE;
         }
      }
   }

   public static boolean toPrimitiveBoolean(String str, boolean defaultValue) {
      if (isNullOrBlank(str)) {
         return defaultValue;
      } else {
         str = str.trim().toLowerCase();
         String[] var2;
         int var3;
         int var4;
         String s;
         if (defaultValue) {
            var2 = FALSE_STRINGS;
            var3 = var2.length;

            for(var4 = 0; var4 < var3; ++var4) {
               s = var2[var4];
               if (s.equals(str)) {
                  return false;
               }
            }

            return true;
         } else {
            var2 = TRUE_STRINGS;
            var3 = var2.length;

            for(var4 = 0; var4 < var3; ++var4) {
               s = var2[var4];
               if (s.equals(str)) {
                  return true;
               }
            }

            return false;
         }
      }
   }

   public static Date toDate(String str, String... formats) throws IllegalArgumentException, ParseException {
      if (isNullOrBlank(str)) {
         return null;
      } else {
         String[] ripeFormats = formats.length > 0 ? formats : DATE_FORMATS;
         List<SimpleDateFormat> sdfs = new ArrayList();
         String[] var4 = ripeFormats;
         int var5 = ripeFormats.length;

         for(int var6 = 0; var6 < var5; ++var6) {
            String format = var4[var6];
            if (format != null) {
               SimpleDateFormat sdf = new SimpleDateFormat(format);
               sdfs.add(sdf);
            }
         }

         ParseException pe = null;
         Iterator var11 = sdfs.iterator();

         while(var11.hasNext()) {
            SimpleDateFormat sdf = (SimpleDateFormat)var11.next();

            try {
               return sdf.parse(str.trim());
            } catch (ParseException var9) {
               pe = var9;
            }
         }

         throw pe;
      }
   }

   public static Date toDate(String str, Date defaultValue, String... formats) throws IllegalArgumentException {
      if (isNullOrBlank(str)) {
         return defaultValue;
      } else {
         String[] ripeFormats = formats.length > 0 ? formats : DATE_FORMATS;
         List<SimpleDateFormat> sdfs = new ArrayList();
         String[] var5 = ripeFormats;
         int var6 = ripeFormats.length;

         for(int var7 = 0; var7 < var6; ++var7) {
            String format = var5[var7];
            if (format != null) {
               SimpleDateFormat sdf = new SimpleDateFormat(format);
               sdfs.add(sdf);
            }
         }

         Iterator var11 = sdfs.iterator();

         while(var11.hasNext()) {
            SimpleDateFormat sdf = (SimpleDateFormat)var11.next();

            try {
               return sdf.parse(str.trim());
            } catch (ParseException var10) {
            }
         }

         return defaultValue;
      }
   }

   public static <T extends Enum> T toEnum(String str, Class<T> enumClass) {
      return toEnum(str, enumClass, (Enum)null);
   }

   public static <T extends Enum> T toEnum(String str, Class<T> enumClass, T defaultValue) {
      if (isNullOrBlank(str)) {
         return defaultValue;
      } else {
         str = str.trim();
         Iterator var3 = EnumSet.allOf(enumClass).iterator();

         Object value;
         do {
            if (!var3.hasNext()) {
               return defaultValue;
            }

            value = var3.next();
         } while(!((Enum)value).name().equalsIgnoreCase(str));

         return (Enum)value;
      }
   }

   public static String toString(Object value) {
      return toString(value, (String)null);
   }

   public static String toString(Object value, String nullString) {
      if (value == null) {
         return nullString;
      } else if (value instanceof Date) {
         return dateToString((Date)value, "yyyy-M-d HH:mm:ss.SSS", nullString);
      } else {
         return value instanceof Enum ? ((Enum)value).name() : value.toString();
      }
   }

   public static String toString(int value) {
      return String.valueOf(value);
   }

   public static String toString(int value, int radix) {
      if (radix < 2 || radix > 36) {
         radix = 10;
      }

      if (radix == 2) {
         return Integer.toBinaryString(value);
      } else if (radix == 8) {
         return Integer.toOctalString(value);
      } else if (radix == 16) {
         return Integer.toHexString(value);
      } else {
         return radix == 10 ? Integer.toString(value) : Integer.toString(value, radix);
      }
   }

   public static String toString(long value) {
      return String.valueOf(value);
   }

   public static String toString(long value, int radix) {
      if (radix < 2 || radix > 36) {
         radix = 10;
      }

      if (radix == 2) {
         return Long.toBinaryString(value);
      } else if (radix == 8) {
         return Long.toOctalString(value);
      } else if (radix == 16) {
         return Long.toHexString(value);
      } else {
         return radix == 10 ? Long.toString(value) : Long.toString(value, radix);
      }
   }

   public static String toString(boolean value) {
      return value ? "true" : "false";
   }

   public static String toString(float value) {
      return String.valueOf(value);
   }

   public static String toString(double value) {
      return String.valueOf(value);
   }

   public static String integerToString(Integer value, int radix) {
      return integerToString(value, radix, (String)null);
   }

   public static String integerToString(Integer value, int radix, String nullString) {
      if (radix < 2 || radix > 36) {
         radix = 10;
      }

      if (value == null) {
         return nullString;
      } else if (radix == 2) {
         return Integer.toBinaryString(value);
      } else if (radix == 8) {
         return Integer.toOctalString(value);
      } else if (radix == 16) {
         return Integer.toHexString(value);
      } else {
         return radix == 10 ? value.toString() : Integer.toString(value, radix);
      }
   }

   public static String longToString(Long value, int radix) {
      return longToString(value, radix, (String)null);
   }

   public static String longToString(Long value, int radix, String nullString) {
      if (radix < 2 || radix > 36) {
         radix = 10;
      }

      if (value == null) {
         return nullString;
      } else if (radix == 2) {
         return Long.toBinaryString(value);
      } else if (radix == 8) {
         return Long.toOctalString(value);
      } else if (radix == 16) {
         return Long.toHexString(value);
      } else {
         return radix == 10 ? value.toString() : Long.toString(value, radix);
      }
   }

   public static String dateToString(Date value, String format) throws IllegalArgumentException {
      return dateToString(value, format, (String)null);
   }

   public static String dateToString(Date value, String format, String nullString) throws IllegalArgumentException {
      if (value == null) {
         return nullString;
      } else {
         if (format == null) {
            format = "yyyy-M-d HH:mm:ss.SSS";
         }

         SimpleDateFormat sdf = new SimpleDateFormat(format);
         return sdf.format(value);
      }
   }

   public static boolean containsMultiBytesChar(String str) {
      if (str == null) {
         return false;
      } else {
         return str.getBytes().length != str.length();
      }
   }

   public static boolean containsChinese(String str) {
      return containsMultiBytesChar(str);
   }
}
